package bookRecommend;
/**
 * This class represents a user (Member) in the system.
 * 
 */
public interface IMember {

	/**
	 * Returns the name of the member
	 * 
	 * @return the name of the member
	 */
	public String getName();

	/**
	 * Returns the unique ID number of the member
	 * 
	 * @return the unique ID number of the member
	 */
	public int getID();

	/**
	 * Adds a rating of a book to the personal rating list of this member
	 * @pre (rating!=null)
	 * @param rating
	 */
	public void addRating(IRating rating);

	/**
	 * Returns the array representation of the members ratings. For example if there are 3 books in the system and the user only rated book where bookID==2 with rating score=5 then @ret==[0,0,5]
	 * if (totalNumberOfBooks==0) $ret=null
	 *  
	 * @param totalNumberOfBooks
	 * @return the array representation of the members ratings
	 */
	public int[] getRatingArray(int totalNumberOfBooks);

	/**
	 * Returns true iff this member equals to the other member. Note that it is possible to have 2 members with the same name (but each member has a unique ID).
	 * 
	 * @param other
	 * @return true iff this member equals to the other member
	 */
	public boolean equals(IMember other);
	
	/**
	 * Returns true iff this member has rated all books currently in our system.
	 * 
	 * @return true iff this member has rated all books currently in our system.
	 */
	public boolean hasReadAllBooksInSystem(int numOfBooksInSystem);

}